@@ -78,6 +78,19 @@
    ;; public-key encryption/signature padding
    #:oaep-encode #:oaep-decode #:pss-encode #:pss-verify
 
+   ;; elliptic curve operations
+   #:ec-point-on-curve-p #:ec-point-equal
+   #:ec-double #:ec-add #:ec-scalar-mult #:ec-scalar-inv
+   #:ec-make-point #:ec-destructure-point
+   #:ec-encode-scalar #:ec-decode-scalar
+   #:ec-encode-point #:ec-decode-point
+
+   ;; elliptic curve points
+   #:curve25519-point #:curve448-point
+   #:ed25519-point #:ed448-point
+   #:secp256k1-point #:secp256r1-point
+   #:secp384r1-point #:secp521r1-point
+
    ;; public/private keys
    #:curve25519-public-key #:curve25519-private-key
    #:curve448-public-key #:curve448-private-key
@@ -157,7 +170,7 @@
    #:with-encrypting-stream #:with-decrypting-stream
    #:make-authenticating-stream #:with-authenticating-stream)
   ;; supported digests
-  (:export #:whirlpool #:md2 #:md4 #:md5 #:adler32 #:crc24 #:crc32
+  (:export #:whirlpool #:md2 #:md4 #:md5 #:adler32 #:crc24 #:crc32 #:crc32c
            #:tiger #:sha1 #:sha224 #:sha256 #:sha384 #:sha512
            #:tree-hash #:make-tiger-tree-hash #:ripemd-128 #:ripemd-160
            #:skein256 #:skein256/128 #:skein256/160 #:skein256/224
@@ -220,11 +233,13 @@
              :32-bit
              :64-bit)
          :ironclad-fast-mod32-arithmetic
-         (when (member :x86-64 *features*)
-           (list* :ironclad-fast-mod64-arithmetic
-                  (let ((sym (find-symbol "EA" :sb-vm)))
-                    (when (and sym (fboundp sym))
-                      '(:ironclad-sb-vm-ea))))))
+         (cond ((member :x86-64 *features*)
+                (list* :ironclad-fast-mod64-arithmetic
+                       (let ((sym (find-symbol "EA" :sb-vm)))
+                         (when (and sym (fboundp sym))
+                           '(:ironclad-sb-vm-ea)))))
+               ((member :arm64 *features*)
+                '(:ironclad-fast-mod64-arithmetic))))
   #+cmu
   (list (c:backend-byte-order c:*target-backend*)
         (if (= vm:word-bits 32)
