@@ -73,7 +73,7 @@
 
 #.(if (boundp '*cipher-stream-tests*)
       (loop for cipher in (crypto:list-all-ciphers)
-            collect `(rtest:deftest ,(intern (format nil "~A/~A" cipher '#:stream))
+            collect `(rtest:deftest ,(crypto::symbolicate cipher '#:/stream)
                        (run-test-vector-file ',cipher *cipher-stream-tests*) t)
               into forms
          finally (return `(progn ,@forms)))
